==> trmaid-0.5.7-py2.py3-none-any.whl: trmaid/plugins.py <==
#!/usr/bin/env python
# encoding=utf-8
import sys

import feedparser
import requests

if sys.version_info[0] < 3:
    from urllib import unquote
else:
    from urllib.parse import unquote


plugins = {}


def register_plugin(name):
    def wrap(cls):
        plugins[name] = cls
        return cls
    return wrap


class Plugin(object):
    check_duplicates = True

    def __init__(self, key, rds=None, textme=None):
        self.key = key
        self.rds = rds
        self.textme = textme

    def get_links(self):
        for link in self._get_links():
            if self.textme:
                link = self.textme(link)
            yield link


@register_plugin('redis')
class RedisPlugin(Plugin):
    check_duplicates = False

    def _get_links(self):
        if self.rds:
            while 1:
                link = self.rds.lpop(self.key)
                if not link:
                    break
                yield link


@register_plugin('rss')
class RSSPlugin(Plugin):

    def _get_links(self):
        for entry in feedparser.parse(self.key).entries:
            if not entry.link:
                continue
            yield unquote(entry.link)


@register_plugin('json')
class JSONPlugin(Plugin):

    def _get_links(self):
        data = requests.get(self.key).json()
        if isinstance(data, list):
            data = {
                'items': data,
            }
        for item in data.get('items', []):
            yield item['link']


if __name__ == '__main__':
    print(plugins)

==> trmaid-0.6-py2.py3-none-any.whl: trmaid/plugins.py <==
#!/usr/bin/env python
# encoding=utf-8
import sys

import feedparser
import requests

if sys.version_info[0] < 3:
    from urllib import unquote
else:
    from urllib.parse import unquote


plugins = {}


def register_plugin(name):
    def wrap(cls):
        plugins[name] = cls
        return cls
    return wrap


class Plugin(object):
    check_duplicates = True

    def __init__(self, key, rds=None, textme=None):
        self.key = key
        self.rds = rds
        self.textme = textme

    def get_links(self):
        for link in self._get_links():
            if self.textme:
                link = self.textme(link)
            yield link


@register_plugin('redis')
class RedisPlugin(Plugin):
    check_duplicates = False

    def _get_links(self):
        if self.rds:
            while 1:
                link = self.rds.lpop(self.key)
                if not link:
                    break
                yield None, link


@register_plugin('rss')
class RSSPlugin(Plugin):

    def _get_links(self):
        for entry in feedparser.parse(self.key).entries:
            if not entry.link:
                continue
            yield entry.title, unquote(entry.link)


@register_plugin('json')
class JSONPlugin(Plugin):

    def _get_links(self):
        data = requests.get(self.key).json()
        if isinstance(data, list):
            data = {
                'items': data,
            }
        for item in data.get('items', []):
            if 'title' in item:
                title = item['title']
            else:
                title = None
            yield title, item['link']


if __name__ == '__main__':
    print(plugins)
